@@ -18,6 +18,7 @@ from cli.consts import SECRET_SCAN_TYPE, INFRA_CONFIGURATION_SCAN_TYPE, INFRA_CO
 from cli.config import configuration_manager
 from cli.utils.path_utils import is_sub_path, is_binary_file, get_file_size, get_relevant_files_in_path, get_path_by_os
 from cli.utils.string_utils import get_content_size, is_binary_content
+from cli.user_settings.config_file_manager import ConfigFileManager
 from cli.zip_file import InMemoryZip
 from cli.exceptions.custom_exceptions import CycodeError, HttpUnauthorizedError, ZipTooLargeError
 from cyclient import logger
@@ -39,7 +40,7 @@ def scan_repository(context: click.Context, path, branch):
     try:
         logger.debug('Starting repository scan process, %s', {'path': path, 'branch': branch})
         documents_to_scan = [
-            Document(get_path_by_os(obj.path), obj.data_stream.read().decode('utf-8', errors='replace'))
+            Document(get_path_by_os(os.path.join(path, obj.path)), obj.data_stream.read().decode('utf-8', errors='replace'))
             for obj
             in get_git_repository_tree_file_entries(path, branch)]
         documents_to_scan = exclude_irrelevant_documents_to_scan(context, documents_to_scan)
@@ -82,12 +83,13 @@ def scan_commit_range(context: click.Context, path: str, commit_range: str):
         parent = commit.parents[0] if commit.parents else NULL_TREE
         diff = commit.diff(parent, create_patch=True, R=True)
         for blob in diff:
-            doc = Document(get_path_by_os(get_diff_file_path(blob)),
+            doc = Document(get_path_by_os(os.path.join(path, get_diff_file_path(blob))),
                            blob.diff.decode('utf-8', errors='replace'), True, commit_id)
             documents_to_scan.append(doc)
 
             documents_to_scan = exclude_irrelevant_documents_to_scan(context, documents_to_scan)
-            logger.debug('Found all relevant files for scanning %s', {'path': path, 'commit_range': commit_range})
+            logger.debug('Found all relevant files in commit %s',
+                         {'path': path, 'commit_range': commit_range, 'commit_id': commit_id})
     return scan_documents(context, documents_to_scan, is_git_diff=True, is_commit_range=True)
 
 
@@ -142,7 +144,7 @@ def scan_documents(context: click.Context, documents_to_scan: List[Document],
     error_message = None
     all_detections_count = 0
     output_detections_count = 0
-    scan_id = uuid4()
+    scan_id = _get_scan_id(context)
     zipped_documents = InMemoryZip()
 
     try:
@@ -397,7 +399,8 @@ def _does_document_exceed_max_size_limit(content: str) -> bool:
 
 def _is_subpath_of_cycode_configuration_folder(filename: str) -> bool:
     return is_sub_path(configuration_manager.global_config_file_manager.get_config_directory_path(), filename) \
-           or is_sub_path(configuration_manager.local_config_file_manager.get_config_directory_path(), filename)
+           or is_sub_path(configuration_manager.local_config_file_manager.get_config_directory_path(), filename) \
+           or filename.endswith(ConfigFileManager.get_config_file_route())
 
 
 def _handle_exception(context: click.Context, e: Exception):
@@ -452,3 +455,9 @@ def _report_scan_status(context: click.Context, scan_type: str, scan_id: str, sc
     except Exception as e:
         logger.debug('Failed to report scan status, %s', {'exception_message': str(e)})
         pass
+
+
+def _get_scan_id(context: click.Context):
+    scan_id = uuid4()
+    context.obj['scan_id'] = scan_id
+    return scan_id
