@@ -15,9 +15,11 @@ SECRET_SCAN_FILE_EXTENSIONS_TO_IGNORE = [
 ]
 
 DEFAULT_CYCODE_API_URL = "https://api.cycode.com"
+DEFAULT_CYCODE_APP_URL = "https://app.cycode.com"
 
 # env var names
-CYCODE_API_URL_VAR_NAME = "CYCODE_API_URL"
+CYCODE_API_URL_ENV_VAR_NAME = "CYCODE_API_URL"
+CYCODE_APP_URL_ENV_VAR_NAME = "CYCODE_APP_URL"
 TIMEOUT_ENV_VAR_NAME = "TIMEOUT"
 LOGGING_LEVEL_ENV_VAR_NAME = "LOGGING_LEVEL"
 # use only for dev envs locally
