@@ -3,10 +3,12 @@ import click
 import sys
 from cli.config import config
 from cli import code_scanner, __version__
-from cyclient import ScanClient, K8SUpdaterClient, logger
+from cyclient import ScanClient, logger
 from cli.user_settings.credentials_manager import CredentialsManager
 from cli.user_settings.user_settings_commands import set_credentials, add_exclusions
+from cli.auth.auth_command import authenticate
 from cli.user_settings.configuration_manager import ConfigurationManager
+from cli.auth.auth_manager import AuthManager
 
 CONTEXT = dict()
 ISSUE_DETECTED_STATUS_CODE = 1
@@ -72,7 +74,7 @@ def code_scan(context: click.Context, scan_type, client_id, secret, show_secret,
 
     context.obj["scan_type"] = scan_type
     context.obj["output"] = output
-    context.obj["client"] = get_cycode_client(client_id, secret, "code_scan")
+    context.obj["client"] = get_cycode_client(client_id, secret)
 
     return 1
 
@@ -90,7 +92,8 @@ def finalize(context: click.Context, *args, **kwargs):
     commands={
         "scan": code_scan,
         "configure": set_credentials,
-        "ignore": add_exclusions
+        "ignore": add_exclusions,
+        "auth": authenticate
     },
     context_settings=CONTEXT
 )
@@ -108,7 +111,7 @@ def main_cli(context: click.Context, verbose: bool):
     logger.setLevel(log_level)
 
 
-def get_cycode_client(client_id, client_secret, execution_type):
+def get_cycode_client(client_id, client_secret):
     if not client_id or not client_secret:
         client_id, client_secret = _get_configured_credentials()
         if not client_id:
@@ -116,10 +119,7 @@ def get_cycode_client(client_id, client_secret, execution_type):
         if not client_secret:
             raise click.ClickException("Cycode client secret is needed.")
 
-    if execution_type == "code_scan":
-        return ScanClient(client_secret=client_secret, client_id=client_id)
-
-    return K8SUpdaterClient(client_secret=client_secret, client_id=client_id)
+    return ScanClient(client_secret=client_secret, client_id=client_id)
 
 
 def _get_configured_credentials():
