@@ -6,7 +6,7 @@ class CycodeError(Exception):
         super().__init__(self.error_message)
 
     def __str__(self):
-        return f'error occurred during scan request. status code: {self.status_code}, error message: ' \
+        return f'error occurred during the request. status code: {self.status_code}, error message: ' \
                f'{self.error_message}'
 
 
@@ -27,3 +27,12 @@ class ZipTooLargeError(Exception):
 
     def __str__(self):
         return f'The size of zip to scan is too large, size limit: {self.size_limit}'
+
+
+class AuthProcessError(Exception):
+    def __init__(self, error_message: str):
+        self.error_message = error_message
+        super().__init__()
+
+    def __str__(self):
+        return f'Something went wrong during the authentication process, error message: {self.error_message}'
