@@ -11,5 +11,14 @@ class JsonPrinter(BasePrinter):
         detections = [detection for document_detections in results for detection in document_detections.detections]
         detections_schema = DetectionSchema(many=True)
         detections_dict = detections_schema.dump(detections)
-        json_result = json.dumps(detections_dict, indent=4)
-        click.secho(json_result, fg='white')
+        json_result = self._get_json_result(context, detections_dict)
+        click.secho(json_result)
+
+    def _get_json_result(self, context, detections):
+        scan_id = context.obj.get('scan_id')
+        result = {
+            'scan_id': str(scan_id),
+            'detections': detections
+        }
+
+        return json.dumps(result, indent=4)
