@@ -11,25 +11,21 @@ class ConfigFileManager(BaseFileManager):
     ENVIRONMENT_SECTION_NAME: str = 'environment'
     EXCLUSIONS_SECTION_NAME: str = 'exclusions'
 
-    BASE_URL_FIELD_NAME: str = 'cycode_base_url'
+    API_URL_FIELD_NAME: str = 'cycode_api_url'
+    APP_URL_FIELD_NAME: str = 'cycode_app_url'
     VERBOSE_FIELD_NAME: str = 'verbose'
 
     def __init__(self, path):
         self.path = path
 
-    def get_base_url(self) -> Optional[str]:
-        file_content = self.read_file()
+    def get_api_url(self) -> Optional[str]:
+        return self._get_value_from_environment_section(self.API_URL_FIELD_NAME)
 
-        environment_section = file_content.get(self.ENVIRONMENT_SECTION_NAME, {})
-        base_url = environment_section.get(self.BASE_URL_FIELD_NAME)
-        return base_url
+    def get_app_url(self) -> Optional[str]:
+        return self._get_value_from_environment_section(self.APP_URL_FIELD_NAME)
 
     def get_verbose_flag(self) -> Optional[bool]:
-        file_content = self.read_file()
-
-        environment_section = file_content.get(self.ENVIRONMENT_SECTION_NAME, {})
-        verbose_flag = environment_section.get(self.VERBOSE_FIELD_NAME)
-        return verbose_flag
+        return self._get_value_from_environment_section(self.VERBOSE_FIELD_NAME)
 
     def get_exclusions_by_scan_type(self, scan_type) -> Dict:
         file_content = self.read_file()
@@ -40,7 +36,7 @@ class ConfigFileManager(BaseFileManager):
     def update_base_url(self, base_url: str):
         update_data = {
             self.ENVIRONMENT_SECTION_NAME: {
-                self.BASE_URL_FIELD_NAME: base_url
+                self.API_URL_FIELD_NAME: base_url
             }
         }
         self.write_content_to_file(update_data)
@@ -67,6 +63,16 @@ class ConfigFileManager(BaseFileManager):
     def get_filename(self) -> str:
         return os.path.join(self.get_config_directory_path(), self.FILE_NAME)
 
+    @staticmethod
+    def get_config_file_route() -> str:
+        return os.path.join(ConfigFileManager.CYCODE_HIDDEN_DIRECTORY, ConfigFileManager.FILE_NAME)
+
     def _get_exclusions_by_exclusion_type(self, scan_type, exclusion_type) -> List:
         scan_type_exclusions = self.get_exclusions_by_scan_type(scan_type)
         return scan_type_exclusions.get(exclusion_type, [])
+
+    def _get_value_from_environment_section(self, field_name: str):
+        file_content = self.read_file()
+        environment_section = file_content.get(self.ENVIRONMENT_SECTION_NAME, {})
+        value = environment_section.get(field_name)
+        return value
