@@ -1,7 +1,6 @@
 """Cycode Client"""
-from .client import CycodeClient
+from .cycode_client import CycodeClient
 from .scan_client import ScanClient
-from .k8s_updater_client import K8SUpdaterClient
 from .config import logger
 
 __version__ = "0.0.15"
@@ -9,6 +8,5 @@ __version__ = "0.0.15"
 __all__ = [
     "CycodeClient",
     "ScanClient",
-    "K8SUpdaterClient",
     "logger"
 ]
